@@ -5,3 +5,5 @@ from teacher import Teacher, TeacherCollection
 from section import Section, SectionCollection
 from term import Term, TermCollection
 from course import Course, CourseCollection
+from attendance import Attendance, AttendanceCollection
+from course_grade import CourseGrade, CourseGradeCollection
